--
-- ilacombo.vhd - 255-bit ILA/ICON pair
--
--  (c) Copyright Alpha Data Ltd. 2005
--
-- SYNTHESIZABLE
--
-- When used to monitor local bus, trig0 assignments are as follows:
--
-- trig0[31:0]        lad[31:0] / ld[31:0]
-- trig0[63:32]       lad[63:0] / la[31:0]
-- trig0[67:64]       lbe[3:0] (active high)
-- trig0[71:68]       lbe[7:4] if present, otherwise 1s (active high)
-- trig0[72]          lreset (active high)
-- trig0[73]          fhold
-- trig0[74]          fholda
-- trig0[75]          lads (active high)
-- trig0[76]          lblast (active high)
-- trig0[77]          lwrite (active high)
-- trig0[78]          l64 (active high)
-- trig0[79]          lready (active high)
-- trig0[80]          lbterm (active high)
-- trig0[87:81]       RESERVED
-- trig0[89:88]       ldreq[1:0] (active high)
-- trig0[91:90]       RESERVED
-- trig0[93:92]       ldack[1:0] (active high)
-- trig0[254:94]      RESERVED
--

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_misc.all;

library work;
use work.ilap.all;

entity ilacombo is
    generic(
        dummy       : in    boolean := false);
    port(
        clk         : in    std_logic;
        trig0       : in    std_logic_vector(254 downto 0);
        trig_out    : out   std_logic);
end ilacombo;

architecture struct of ilacombo is

    signal control0 : std_logic_vector(35 downto 0);

    signal logic0 : std_logic;

    attribute syn_hier : string;
    attribute syn_hier of struct : architecture is "hard";

begin

    logic0 <= '0';

    instantiate : if not dummy generate
        i_icon : icon
            port map(
                control0   => control0);

        i_ila : ila
            port map(
                control    => control0,
                clk        => clk,
                trig0      => trig0,
                trig_out   => trig_out);
    end generate;

    instantiate_dummy : if dummy generate
        trig_out <= logic0;
    end generate;

end;
